@@ -1,9 +1,9 @@
-/* $Id: nano.h 4417 2009-11-07 16:56:17Z astyanax $ */
+/* $Id: nano.h 4453 2009-12-02 03:36:22Z astyanax $ */
 /**************************************************************************
  *   nano.h                                                               *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
@@ -54,6 +54,9 @@
 #include <stdarg.h>
 #endif
 
+/* Suppress warnings for __attribute__((warn_unused_result)) */
+#define IGNORE_CALL_RESULT(call) do { if (call) {} } while(0)
+
 /* Macros for flags. */
 #define FLAGOFF(flag) ((flag) / (sizeof(unsigned) * 8))
 #define FLAGMASK(flag) (1 << ((flag) % (sizeof(unsigned) * 8)))
