@@ -1,4 +1,4 @@
-/* $Id: text.c 4462 2009-12-12 22:21:20Z astyanax $ */ 
+/* $Id: text.c 4499 2010-04-14 03:14:40Z astyanax $ */ 
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
@@ -2752,6 +2752,11 @@ const char *do_alt_speller(char *tempfile_name)
     }
 #endif
 
+    if (openfile->totsize == 0) {
+	statusbar(_("Finished checking spelling"));
+	return NULL;
+    }
+
     endwin();
 
     /* Set up an argument list to pass execvp(). */
